@@ -130,4 +130,18 @@ db_save_query.spark_connection <- function(con, sql, name, temporary = TRUE, ...
   # compute() is expected to preserve the query, cache as the closest mapping.
   if (!sparklyr_boolean_option("sparklyr.dplyr.compute.nocache"))
     tbl_cache(con, name)
+
+  # dbplyr expects db_save_query to retrieve the table name
+  name
+}
+
+#' @export
+#' @importFrom dplyr db_analyze
+#' @importFrom dbplyr build_sql
+#' @importFrom DBI dbExecute
+db_analyze.spark_connection <- function(con, table, ...) {
+  info <- dbGetQuery(con, build_sql("SHOW TABLES LIKE", table, con = con))
+  if (nrow(info) > 0 && identical(info$isTemporary, FALSE)) {
+    dbExecute(con, build_sql("ANALYZE TABLE", table, "COMPUTE STATISTICS", con = con))
+  }
 }
