@@ -210,7 +210,6 @@ new_ml_model_multilayer_perceptron_classification <- function(
     pipeline, pipeline_model, model, dataset, formula,
     subclass = "ml_model_multilayer_perceptron_classification",
     .features = feature_names,
-    .index_labels = index_labels,
-    .call = call
+    .index_labels = index_labels
   )
 }
