@@ -13,7 +13,8 @@ object LivyUtils {
     "WorkerHelper" -> WorkerHelper,
     "WorkerUtils" -> WorkerUtils,
     "MLUtils" -> MLUtils,
-    "Shell" -> Shell
+    "MLUtils2" -> MLUtils2,
+    "BucketizerUtils" -> BucketizerUtils
    )
 
   val tracker = new JVMObjectTracker()
